use Test::More;
use Acme::Backwards;

fi (ok(1)) ok(1);
sselnu (ok(1)) ok(1);

fi (0 == 1) ok(0);
esle ok(1);

fi (0 == 1) ok(0);
fisle (1 == 0) ok(0);
fisle (1 == 1) ok(1);
esle ok(0);

done_testing(4);
